==> ejc-scheme-impl-3.0.0-20210329.100823-51-sources.jar: com/ejianc/business/scheme/bean/SchemeDocEntity.java <==
package com.ejianc.business.scheme.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工方案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scheme_doc")
public class SchemeDocEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="category_id")
    private java.lang.Long categoryId; // 分类主键
    @TableField(value="scheme_code")
    private java.lang.String schemeCode; // 方案编码
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 方案名称
    @TableField(value="scheme_grade")
    private java.lang.Long schemeGrade; // 方案分级,自定义档案
    @TableField(value="scheme_grade_name")
    private java.lang.String schemeGradeName; // 方案分级名称
    @TableField(value="scheme_parameter")
    private java.lang.String schemeParameter; // 方案参数

    /**
     * 分类主键
     */
    public java.lang.Long getCategoryId() {
        return categoryId;
    }

    /**
     * 分类主键
     */
    public void setCategoryId(java.lang.Long categoryId) {
        this.categoryId = categoryId;
    }
    /**
     * 方案编码
     */
    public java.lang.String getSchemeCode() {
        return schemeCode;
    }

    /**
     * 方案编码
     */
    public void setSchemeCode(java.lang.String schemeCode) {
        this.schemeCode = schemeCode;
    }
    /**
     * 方案名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    /**
     * 方案分级,自定义档案
     */
    public java.lang.Long getSchemeGrade() {
        return schemeGrade;
    }

    /**
     * 方案分级,自定义档案
     */
    public void setSchemeGrade(java.lang.Long schemeGrade) {
        this.schemeGrade = schemeGrade;
    }
    /**
     * 方案分级名称
     */
    public java.lang.String getSchemeGradeName() {
        return schemeGradeName;
    }

    /**
     * 方案分级名称
     */
    public void setSchemeGradeName(java.lang.String schemeGradeName) {
        this.schemeGradeName = schemeGradeName;
    }
    /**
     * 方案参数
     */
    public java.lang.String getSchemeParameter() {
        return schemeParameter;
    }

    /**
     * 方案参数
     */
    public void setSchemeParameter(java.lang.String schemeParameter) {
        this.schemeParameter = schemeParameter;
    }
    
}

==> ejc-scheme-impl-3.0.0-20210331.034900-73-sources.jar: com/ejianc/business/scheme/bean/SchemeDocEntity.java <==
package com.ejianc.business.scheme.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 施工方案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scheme_doc")
public class SchemeDocEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="category_id")
    private java.lang.Long categoryId; // 分类主键
    @TableField(value="scheme_code")
    private java.lang.String schemeCode; // 方案编码
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 方案名称
    @TableField(value="scheme_grade")
    private java.lang.Long schemeGrade; // 方案分级,自定义档案
    @TableField(value="scheme_grade_name")
    private java.lang.String schemeGradeName; // 方案分级名称
    @TableField(value="scheme_parameter")
    private java.lang.String schemeParameter; // 方案参数
    @TableField(value="category_name")
    private java.lang.String categoryName; // 方案名称

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    /**
     * 分类主键
     */
    public java.lang.Long getCategoryId() {
        return categoryId;
    }

    /**
     * 分类主键
     */
    public void setCategoryId(java.lang.Long categoryId) {
        this.categoryId = categoryId;
    }
    /**
     * 方案编码
     */
    public java.lang.String getSchemeCode() {
        return schemeCode;
    }

    /**
     * 方案编码
     */
    public void setSchemeCode(java.lang.String schemeCode) {
        this.schemeCode = schemeCode;
    }
    /**
     * 方案名称
     */
    public java.lang.String getSchemeName() {
        return schemeName;
    }

    /**
     * 方案名称
     */
    public void setSchemeName(java.lang.String schemeName) {
        this.schemeName = schemeName;
    }
    /**
     * 方案分级,自定义档案
     */
    public java.lang.Long getSchemeGrade() {
        return schemeGrade;
    }

    /**
     * 方案分级,自定义档案
     */
    public void setSchemeGrade(java.lang.Long schemeGrade) {
        this.schemeGrade = schemeGrade;
    }
    /**
     * 方案分级名称
     */
    public java.lang.String getSchemeGradeName() {
        return schemeGradeName;
    }

    /**
     * 方案分级名称
     */
    public void setSchemeGradeName(java.lang.String schemeGradeName) {
        this.schemeGradeName = schemeGradeName;
    }
    /**
     * 方案参数
     */
    public java.lang.String getSchemeParameter() {
        return schemeParameter;
    }

    /**
     * 方案参数
     */
    public void setSchemeParameter(java.lang.String schemeParameter) {
        this.schemeParameter = schemeParameter;
    }
    
}
